@@ -4,4 +4,4 @@ from .authorization_code import AuthorizationCodeHandler
 from .client import OAuth2Client
 from .client_authentication import (ClientSecretBasic, ClientSecretJWT,
                                     ClientSecretPost, PrivateKeyJWT)
-from .token_response import BearerToken, BearerTokenEndpointResponse
+from .token_response import BearerToken
